==> ejc-bid-impl-3.0.0-20230103.063941-300-sources.jar: com/ejianc/business/bid/bean/BidFileReviewEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标文件评审
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_bid_file_review")
public class BidFileReviewEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="engineering_id")
    private java.lang.Long engineeringId; // 工程
    @TableField(value="engineering_code")
    private java.lang.String engineeringCode; // 工程编码
    @TableField(value="engineering_name")
    private java.lang.String engineeringName; // 工程名称
    @TableField(value="review_date")
    private java.util.Date reviewDate; // 评审日期
    @TableField(value="review_result")
    private java.lang.Integer reviewResult; // 评审结论编码 0同意投标1采取措施后投标2不投标
    @TableField(value="review_result_name")
    private java.lang.String reviewResultName; // 评审结论
    @TableField(value="built_constructor")
    private java.lang.String builtConstructor; // 建造师
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="enroll_id")
    private java.lang.Long enrollId; // 报名ID
    @TableField(value="is_stop")
    private java.lang.Integer isStop; // 是否中止
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 编制人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 编制人
    @TableField(value="bill_date")
    private java.util.Date billDate; // 编制日期
    @TableField(value="make_org_id")
    private java.lang.Long makeOrgId; // 编制机构
    @TableField(value="make_org_name")
    private java.lang.String makeOrgName; // 编制机构
    @TableField(value="built_constructor_id")
    private Long builtConstructorId; // 建造师id
    @TableField(value="zcbh")
    private String zcbh; // 注册编号
    @TableField(value="bid_file_type")
    private Integer bidFileType; // 0:纸质标1：电子标
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="employee_code")
    private String employeeCode; // 编制人编码
    @TableField(value="pid")
    private Long pid; // 建造师人员表id
    @TableField(value="bidding_date")
    private Date biddingDate; // 开标日期


    public Date getBiddingDate() {
        return biddingDate;
    }

    public void setBiddingDate(Date biddingDate) {
        this.biddingDate = biddingDate;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程
     */
    public java.lang.Long getEngineeringId() {
        return engineeringId;
    }

    /**
     * 工程
     */
    public void setEngineeringId(java.lang.Long engineeringId) {
        this.engineeringId = engineeringId;
    }
    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 评审日期
     */
    public java.util.Date getReviewDate() {
        return reviewDate;
    }

    /**
     * 评审日期
     */
    public void setReviewDate(java.util.Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    /**
     * 评审结论编码 0同意投标1采取措施后投标2不投标
     */
    public java.lang.Integer getReviewResult() {
        return reviewResult;
    }

    /**
     * 评审结论编码 0同意投标1采取措施后投标2不投标
     */
    public void setReviewResult(java.lang.Integer reviewResult) {
        this.reviewResult = reviewResult;
    }
    /**
     * 评审结论
     */
    public String getReviewResultName() {
        return reviewResultName;
    }
    /**
     * 评审结论
     */
    public void setReviewResultName(String reviewResultName) {
        this.reviewResultName = reviewResultName;
    }

    /**
     * 建造师
     */
    public java.lang.String getBuiltConstructor() {
        return builtConstructor;
    }

    /**
     * 建造师
     */
    public void setBuiltConstructor(java.lang.String builtConstructor) {
        this.builtConstructor = builtConstructor;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 组织ID
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 报名ID
     */
    public java.lang.Long getEnrollId() {
        return enrollId;
    }

    /**
     * 报名ID
     */
    public void setEnrollId(java.lang.Long enrollId) {
        this.enrollId = enrollId;
    }
    /**
     * 是否中止
     */
    public java.lang.Integer getIsStop() {
        return isStop;
    }

    /**
     * 是否中止
     */
    public void setIsStop(java.lang.Integer isStop) {
        this.isStop = isStop;
    }
    /**
     * 编制人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 编制人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 编制人
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 编制日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 编制机构
     */
    public java.lang.Long getMakeOrgId() {
        return makeOrgId;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgId(java.lang.Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    /**
     * 编制机构
     */
    public java.lang.String getMakeOrgName() {
        return makeOrgName;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgName(java.lang.String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }

    public Long getBuiltConstructorId() {
        return builtConstructorId;
    }

    public void setBuiltConstructorId(Long builtConstructorId) {
        this.builtConstructorId = builtConstructorId;
    }
    public String getZcbh() {
        return zcbh;
    }

    public void setZcbh(String zcbh) {
        this.zcbh = zcbh;
    }
    public Integer getBidFileType() {
        return bidFileType;
    }

    public void setBidFileType(Integer bidFileType) {
        this.bidFileType = bidFileType;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
}

==> ejc-bid-impl-3.0.0-20231008.020252-374-sources.jar: com/ejianc/business/bid/bean/BidFileReviewEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标文件评审
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_bid_file_review")
public class BidFileReviewEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="engineering_id")
    private java.lang.Long engineeringId; // 工程
    @TableField(value="engineering_code")
    private java.lang.String engineeringCode; // 工程编码
    @TableField(value="engineering_name")
    private java.lang.String engineeringName; // 工程名称
    @TableField(value="review_date")
    private java.util.Date reviewDate; // 评审日期
    @TableField(value="review_result")
    private java.lang.Integer reviewResult; // 评审结论编码 0同意投标1采取措施后投标2不投标
    @TableField(value="review_result_name")
    private java.lang.String reviewResultName; // 评审结论
    @TableField(value="built_constructor")
    private java.lang.String builtConstructor; // 建造师
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织ID
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="enroll_id")
    private java.lang.Long enrollId; // 报名ID
    @TableField(value="is_stop")
    private java.lang.Integer isStop; // 是否中止
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 编制人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 编制人
    @TableField(value="bill_date")
    private java.util.Date billDate; // 编制日期
    @TableField(value="make_org_id")
    private java.lang.Long makeOrgId; // 编制机构
    @TableField(value="make_org_name")
    private java.lang.String makeOrgName; // 编制机构
    @TableField(value="built_constructor_id")
    private Long builtConstructorId; // 建造师id
    @TableField(value="zcbh")
    private String zcbh; // 注册编号
    @TableField(value="bid_file_type")
    private Integer bidFileType; // 0:纸质标1：电子标
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="employee_code")
    private String employeeCode; // 编制人编码
    @TableField(value="pid")
    private Long pid; // 建造师人员表id
    @TableField(value="bidding_date")
    private Date biddingDate; // 开标日期
    @TableField(value="bidding_built_constructor_id")
    private Long biddingBuiltConstructorId; // 招标建造师id
    @TableField(value="bidding_built_constructor")
    private String biddingBuiltConstructor; // 招标建造师


    public Long getBiddingBuiltConstructorId() {
        return biddingBuiltConstructorId;
    }

    public void setBiddingBuiltConstructorId(Long biddingBuiltConstructorId) {
        this.biddingBuiltConstructorId = biddingBuiltConstructorId;
    }

    public String getBiddingBuiltConstructor() {
        return biddingBuiltConstructor;
    }

    public void setBiddingBuiltConstructor(String biddingBuiltConstructor) {
        this.biddingBuiltConstructor = biddingBuiltConstructor;
    }

    public Date getBiddingDate() {
        return biddingDate;
    }

    public void setBiddingDate(Date biddingDate) {
        this.biddingDate = biddingDate;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程
     */
    public java.lang.Long getEngineeringId() {
        return engineeringId;
    }

    /**
     * 工程
     */
    public void setEngineeringId(java.lang.Long engineeringId) {
        this.engineeringId = engineeringId;
    }
    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 评审日期
     */
    public java.util.Date getReviewDate() {
        return reviewDate;
    }

    /**
     * 评审日期
     */
    public void setReviewDate(java.util.Date reviewDate) {
        this.reviewDate = reviewDate;
    }
    /**
     * 评审结论编码 0同意投标1采取措施后投标2不投标
     */
    public java.lang.Integer getReviewResult() {
        return reviewResult;
    }

    /**
     * 评审结论编码 0同意投标1采取措施后投标2不投标
     */
    public void setReviewResult(java.lang.Integer reviewResult) {
        this.reviewResult = reviewResult;
    }
    /**
     * 评审结论
     */
    public String getReviewResultName() {
        return reviewResultName;
    }
    /**
     * 评审结论
     */
    public void setReviewResultName(String reviewResultName) {
        this.reviewResultName = reviewResultName;
    }

    /**
     * 建造师
     */
    public java.lang.String getBuiltConstructor() {
        return builtConstructor;
    }

    /**
     * 建造师
     */
    public void setBuiltConstructor(java.lang.String builtConstructor) {
        this.builtConstructor = builtConstructor;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 组织ID
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 报名ID
     */
    public java.lang.Long getEnrollId() {
        return enrollId;
    }

    /**
     * 报名ID
     */
    public void setEnrollId(java.lang.Long enrollId) {
        this.enrollId = enrollId;
    }
    /**
     * 是否中止
     */
    public java.lang.Integer getIsStop() {
        return isStop;
    }

    /**
     * 是否中止
     */
    public void setIsStop(java.lang.Integer isStop) {
        this.isStop = isStop;
    }
    /**
     * 编制人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 编制人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 编制人
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 编制日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 编制机构
     */
    public java.lang.Long getMakeOrgId() {
        return makeOrgId;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgId(java.lang.Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    /**
     * 编制机构
     */
    public java.lang.String getMakeOrgName() {
        return makeOrgName;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgName(java.lang.String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }

    public Long getBuiltConstructorId() {
        return builtConstructorId;
    }

    public void setBuiltConstructorId(Long builtConstructorId) {
        this.builtConstructorId = builtConstructorId;
    }
    public String getZcbh() {
        return zcbh;
    }

    public void setZcbh(String zcbh) {
        this.zcbh = zcbh;
    }
    public Integer getBidFileType() {
        return bidFileType;
    }

    public void setBidFileType(Integer bidFileType) {
        this.bidFileType = bidFileType;
    }

    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
}
